<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=EUC-JP">
<title><?php echo htmlspecialchars($title) ?> [ <?php echo htmlspecialchars(SITE_NAME) ?> ]</title>
<link rel="shortcut icon" href="/favicon.ico">
<?php StylesheetFormlet::show() ?>
<script language="javascript">
function focusing()
{
  if (location.hash == "#QueueList") {
    var input = document.getElementById("queueInput");
    input.focus();
  }
}
</script>
</head>

<body onLoad="focusing()">
<?php include $module; ?>
<div class="footer" align="right">
<p>
powered by SocieWiki <?php echo VERSION ?><br>
Copyright &copy; 2004 SHIMADA Keiki
</p>
</div>
</body>
</html>
